"""
copy_step_images.py v.1.1 (6-16-2020)
Created by Rich Thurau: richard_thurau@ios.doi.gov

Purpose: This script provides two main sorting functions for the FLIR Pro Vue R Duo data:
1. Separates files into a "EO" and "IR" folder within the user selected output folder.
2. If a "Step" value greater than zero (0) is provided, the script will also select a subset of the images. 

"""

import os, glob
from shutil import copyfile

########## User Inputs #####
inDir = r"C:\Photos"
outDir = r"C:\Photos\Out"

EO_ext = ".JPG"
IR_ext = ".TIFF"

Step =  0 #Step 2 is every other photo, 3 every third photo, etc.



#########

IR_Dir = os.path.join(outDir, "IR")
EO_Dir = os.path.join(outDir, "EO")

dir_list = (IR_Dir, EO_Dir)

for Dir in dir_list:
    if not os.path.exists(Dir):
        os.makedirs(Dir)

all_pics = glob.iglob(inDir+"\*")

for pic in all_pics:
    picName = os.path.basename(pic)
    if pic.endswith(EO_ext):
        copyPic = os.path.join(EO_Dir, picName)
        copyfile(pic, copyPic)
    elif pic.endswith(IR_ext):
        copyPic = os.path.join(IR_Dir, picName)
        copyfile(pic, copyPic)

#    print str(picName)+" has been copied to "+ str(outDir)

def step_function(Step):
    for Dir in dir_list:
        all_pics = glob.glob(Dir+"\*")

        step_dir = os.path.join(Dir, "step_"+str(Step))
        os.makedirs(step_dir)
            
        select_pics = all_pics[::Step]
        for pic in select_pics:
            picName = os.path.basename(pic)
            copyPic = os.path.join(step_dir, picName)
            copyfile(pic, copyPic)
            
if Step > 0:
    step_function(Step)
